pub struct LedgerAuth {
pub token_env: Option<String>,
pub token_cmd: Option<String>,
}Expand description
Credentials configuration for registry authentication.
Fields
token_env: Option<String>Name of the environment variable holding the registry token.
token_cmd: Option<String>Shell command whose stdout is used as the registry token.